-- ------------------------------------------------------------------------------ --
--                                TradeSkillMaster                                --
--                          https://tradeskillmaster.com                          --
--    All Rights Reserved - Detailed license information included with addon.     --
-- ------------------------------------------------------------------------------ --

local TSM = select(2, ...) ---@type TSM
local AddonSettings = TSM.Init("App.Lib.AddonSettings") ---@class App.Lib.AddonSettings: TSMModule
local ClientInfo = TSM.LibTSMWoW:Include("Util.ClientInfo")
local L = TSM.Include("Locale").GetTable()
local Table = TSM.LibTSMUtil:Include("Lua.Table")
local TempTable = TSM.LibTSMUtil:Include("BaseType.TempTable")
local CSV = TSM.LibTSMUtil:Include("Format.CSV")
local StaticPopupDialog = TSM.LibTSMWoW:IncludeClassType("StaticPopupDialog")
local Sound = TSM.Include("Util.Sound")
local Settings = TSM.Include("Service.Settings")
local private = {
	db = nil,
}



-- ============================================================================
-- Module Loading
-- ============================================================================

AddonSettings:OnModuleLoad(function()
	TSM.SetSettingsLoader(function()
		local db, upgradeObj = Settings.NewDB("TradeSkillMasterDB", private.GetSchema())
		if upgradeObj then
			private.ProcessUpgrade(db, upgradeObj)
		end
		private.db = db
		return db
	end)
end)

---Gets the addon settings DB
---@return SettingsDB
function AddonSettings.GetDB()
	assert(private.db)
	return private.db
end



-- ============================================================================
-- Private Helper Functions
-- ============================================================================

function private.GetSchema()
	-- Changelog:
	-- [6] added 'global.locale' key
	-- [7] changed default value of 'tsmItemTweetEnabled' to false
	-- [8] added 'global.itemCacheVersion' key
	-- [9] removed 'global.itemCacheVersion' key, added 'global.clientVersion' key
	-- [10] first TSM4 version - combined all module settings into a single DB
	-- [11] added profile.internalData.createdDefaultOperations
	-- [12] added global.shoppingOptions.pctSource
	-- [13] added profile.internalData.{managementGroupTreeContext,auctioningGroupTreeContext,shoppingGroupTreeContext}
	-- [14] added global.userData.savedAuctioningSearches
	-- [15] added global.coreOptions.bankUITab, profile.coreOptions.{bankUIBankFramePosition,bankUIGBankFramePosition}
	-- [16] moved profile.coreOptions.{bankUIBankFramePosition,bankUIGBankFramePosition} to profile.internalData.{bankUIBankFramePosition,bankUIGBankFramePosition}
	-- [17] added global.internalData.{mainUIFrameContext,auctionUIFrameContext,craftingUIFrameContext}
	-- [18] removed global.internalData.itemStringLookup
	-- [19] added sync scope (initially with internalData.{classKey,bagQuantity,bankQuantity,reagentBankQuantity,auctionQuantity,mailQuantity}), removed factionrealm.internalData.{syncMetadata,accountKey,inventory,characters} and factionrealm.coreOptions.syncAccounts, added global.debug.chatLoggingEnabled
	-- [20] added global.tooltipOptions.enabled
	-- [21] added global.craftingOptions.{profitPercent,questSmartCrafting,queueSort}
	-- [22] added global.coreOptions.cleanGuildBank
	-- [23] changed global.shoppingOptions.maxDeSearchPercent default to 100
	-- [24] added global.auctioningOptions.{showAuctionDBTab,openAllBags,ahRowDisplay}
	-- [25] split realm.internalData.goldLog into sync.internalData.goldLog and factionrealm.internalData.guildGoldLog
	-- [26] added profile.internalData.{shoppingTabGroupContext,auctioningTabGroupContext}
	-- [27] added char.internalData.craftingCooldowns
	-- [28] added global.internalData.mailingUIFrameContext
	-- [29] added global.internalData.vendoringUIFrameContext
	-- [30] added global.internalData.bankingUIFrameContext
	-- [31] changed global.internalData.bankingUIFrameContext default (isOpen = true), added profile.internalData.{bankingWarehousingGroupTreeContext,bankingAuctioningGroupTreeContext,bankingMailingGroupTreeContext}
	-- [32] removed factionrealm.internalData.gathering, added factionrealm.internalData.gatheringContext.{crafter,professions}, added profile.gatheringOptions.sources
	-- [33] added global.internalData.taskListUIFrameContext
	-- [34] removed realm.internalData.{lastAuctionDBCompleteScan,lastAuctionDBSaveTime,auctionDBScanData}
	-- [35] added factionrealm.userData.craftingCooldownIgnore
	-- [36] removed factionrealm.internalData.playerProfessions and added sync.internalData.playerProfessions
	-- [37] removed global.auctioningOptions.showAuctionDBTab
	-- [38] removed global.mailingOptions.{defaultMailTab,autoCheck,displayMoneyCollected,deleteEmptyNPCMail,showReloadBtn,sendDelay,defaultPage}, added global.mailingOptions.recentlyMailedList
	-- [39] added profile.internalData.{craftingGroupTreeContext,mailingGroupTreeContext,vendoringGroupTreeContext,importGroupTreeContext}
	-- [40] removed global.accountingOptions.{timeFormat,mvSource}
	-- [41] removed global.coreOptions.groupPriceSource
	-- [42] removed global.vendoringOptions.defaultMerchantTab
	-- [43] removed global.coreOptions.{moveDelay,bankUITab}, removed global.auctioningOptions.{openAllBags,ahRowDisplay}, removed global.craftingOptions.{profitPercent,questSmartCrafting,queueSort}, removed global.destroyingOptions.{logDays,timeFormat}, removed global.vendoringOptions.{autoSellTrash,qsHideGrouped,qsHideSoulbound,qsBatchSize,defaultPage,qsMaxMarketValue,qsDestroyValue}, removed profile.coreOptions.{cleanBags,cleanBank,cleanReagentBank,cleanGuildBank}
	-- [44] changed global.internalData.{mainUIFrameContext,auctionUIFrameContext,craftingUIFrameContext,destroyingUIFrameContext,mailingUIFrameContext,vendoringUIFrameContext,bankingUIFrameContext} default (added "scale = 1")
	-- [45] added char.internalData.auctionSaleHints
	-- [46] added global.shoppingOptions.{buyoutConfirm,buyoutAlertSource}
	-- [47] added factionrealm.internalData.expiringMail and factionrealm.internalData.expiringAuction
	-- [48] added profile.internalData.exportGroupTreeContext
	-- [49] added factionrealm.internalData.{mailDisenchantablesChar,mailExcessGoldChar,mailExcessGoldLimit}
	-- [50] added factionrealm.internalData.{csvAuctionDBScan,auctionDBScanTime,auctionDBScanHash}
	-- [51-53] resetting factionrealm.internalData.crafts
	-- [54] removed global.coreOptions.{tsmItemTweetEnabled,auctionSaleEnabled,auctionBuyEnabled}
	-- [55] added global.auctionUIContext.{auctioningSelectionDividedContainer,auctioningBagScrollingTable,auctioningLogScrollingTable,auctioningAuctionScrollingTable,myAuctionsScrollingTable,shoppingSelectionDividedContainer,shoppingAuctionScrollingTable,sniperScrollingTable,frame,showDefault,shoppingSearchesTabGroup}
	--  added global.bankingUIContext.{frame,isOpen,tab}
	--  added global.craftingUIContext.{craftsScrollingTable,matsScrollingTable,gatheringDividedContainer,gatheringScrollingTable,professionScrollingTable,frame,showDefault,professionDividedContainer}
	--  added global.destroyingUIContext.itemsScrollingTable
	--  added global.mailingUIContext.{mailsScrollingTable,frame,showDefault}
	--  added global.mainUIContext.{ledgerDetailScrollingTable,ledgerInventoryScrollingTable,ledgerAuctionsScrollingTable,ledgerOtherScrollingTable,ledgerTransactionsScrollingTable,ledgerResaleScrollingTable,frame,dashboardDividedContainer,groupsDividedContainer,operationsDividedContainer,importExportDividedContainer}
	--  added global.taskListUIContext.{frame,isOpen}
	--  added global.vendoringUIContext.{buyScrollingTable,buybackScrollingTable,sellScrollingTable,frame,showDefault}
	--  added profile.mainUIContext.{groupsManagementGroupTree,importGroupTree,exportGroupTree}
	--  added profile.auctionUIContext.{auctioningTabGroup,auctioningGroupTree,shoppingGroupTree}
	--  added profile.bankingUIContext.{warehousingGroupTree,auctioningGroupTree,mailingGroupTree}
	--  added profile.craftingUIContext.groupTree
	--  added profile.mailingUIContext.groupTree
	--  added profile.vendoringUIContext.groupTree
	--  removed profile.internalData.{auctioningTabGroupContext,auctioningGroupTreeContext,managementGroupTreeContext,shoppingGroupTreeContext,importGroupTreeContext,exportGroupTreeContext,bankingUIFrameContext,craftingUIFrameContext,auctionUIFrameContext,mailingUIFrameContext,vendoringUIFrameContext,destroyingUIFrameContext,mainUIFrameContext,taskListUIFrameContext}
	-- [56] added factionrealm.internalData.isCraftFavorite
	-- [57] updated global.auctionUIContext.auctioningAuctionScrollingTable
	-- [58] updated global.auctionUIContext.sniperScrollingTable
	-- [59] updated global.mainUIContext.{frame,dashboardDividedContainer,ledgerDetailScrollingTable,ledgerInventoryScrollingTable,ledgerAuctionsScrollingTable,ledgerOtherScrollingTable,ledgerTransactionsScrollingTable,ledgerResaleScrollingTable}
	-- [60] updated global.auctionUIContext.{auctioningAuctionScrollingTable,shoppingAuctionScrollingTable,sniperScrollingTable}, global.craftingUIContext.professionScrollingTable
	-- [61] updated global.auctionUIContext.sniperScrollingTable
	-- [62] updated global.mainUIContext.{ledgerTransactionsScrollingTable,ledgerResaleScrollingTable}
	-- [63] removed global.auctioningOptions.roundNormalPrice
	-- [64] removed global.accountingOptions.smartBuyPrice
	-- [65] added global.appearanceOptions.colorSet
	-- [66] added global.auctionUIContext.auctioningSelectionVerticalDividedContainer
	-- [67] updated global.mailingUIContext.mailsScrollingTable
	-- [68] removed profile.internalData.{bankUIBankFramePosition,bankUIGBankFramePosition,shoppingTabGroupContext,bankingWarehousingGroupTreeContext,bankingAuctioningGroupTreeContext,bankingMailingGroupTreeContext,craftingGroupTreeContext,mailingGroupTreeContext,vendoringGroupTreeContext}
	-- [69] updated global.mainUIContext.ledgerInventoryScrollingTable
	-- [70] updated global.auctionUIContext.{auctioningAuctionScrollingTable,shoppingAuctionScrollingTable}
	-- [71] moved profile.auctionUIContext.{auctioningGroupTree,shoppingGroupTree},profile.bankingUIContext.{warehousingGroupTree,auctioningGroupTree,mailingGroupTree},profile.craftingUIContext.groupTree,profile.mailingUIContext.groupTree,profile.mainUIContext.{groupsManagementGroupTree,importGroupTree,exportGroupTree} to char.*
	-- [72] updated global.auctionUIContext.sniperScrollingTable
	-- [73] added profile.vendoringUIContext.groupTree
	-- [74] added sync.internalData.money
	-- [75] updated global.appearanceOptions.colorSet
	-- [76] updated global.mainUIContext.operationsSummaryScrollingTable
	-- [77] added global.coreOptions.protectAuctionHouse
	-- [78] added global.mainUIContext.{dashboardUnselectedCharacters,dashboardTimeRange}
	-- [79] updated global.shoppingOptions.maxDeSearchLvl
	-- [80] updated char.auctionUIContext.{auctioningGroupTree,shoppingGroupTree},char.bankingUIContext.{warehousingGroupTree,auctioningGroupTree,mailingGroupTree},char.craftingUIContext.groupTree,char.mailingUIContext.groupTree,char.vendoringUIContext.groupTree,char.mainUIContext.{importGroupTree,exportGroupTree}
	-- [81] updated global.mailingUIContext.mailsScrollingTable
	-- [82] updated global.craftingUIContext.professionScrollingTable
	-- [83] added sync.internalData.goldLogLastUpdate, factionrealm.internalData.guildGoldLogLastUpdate
	-- [84] added global.auctionUIContext.myAuctionsScrollingTable
	-- [85] removed global.craftingOptions.ignoreCDCraftCost
	-- [86] updated global.craftingUIContext.craftsScrollingTable
	-- [87] added global.craftingUIContext.craftsScrollingTable
	-- [88] added global.shoppingOptions.searchAutoFocus
	-- [89] updated global.craftingOptions.defaultCraftPriceMethod
	-- [90] added global.internalData.lastCharacter
	-- [91] updated global.craftingUIContext.professionScrollingTable
	-- [92] updated global.vendoringUIContext.buyScrollingTable
	-- [93] moved profile.auctionUIContext.auctioningTabGroup to global.auctionUIContext.auctioningTabGroup
	-- [94] added global.internalData.whatsNewVersion
	-- [95] added global.appearanceOptions.showTotalMoney
	-- [96] updated global.userData.{savedShoppingSearches,savedAuctioningSearches}
	-- [97] added global.internalData.{optionalMatBonusIdLookup,optionalMatTextLookup}
	-- [98] added global.appearanceOptions.customColorSet
	-- [99] updated factionrealm.internalData.crafts, factionrealm.userData.craftingCooldownIgnore, char.internalData.craftingCooldowns
	-- [100] added factionrealm.internalData.craftingQueue
	-- [101] updated factionrealm.internalData.craftingQueue
	-- [102] removed global.internalData.optionalMatBonusIdLookup
	-- [103] updated global.auctionUIContext.auctioningAuctionScrollingTable, global.auctionUIContext.myAuctionsScrollingTable, global.auctionUIContext.shoppingAuctionScrollingTable, global.auctionUIContext.sniperScrollingTable, global.auctionUIContext.professionScrollingTable
	-- [104] removed factionrealm.internalData.{csvAuctionDBScan,auctionDBScanTime,auctionDBScanHash}
	-- [105] updated factionrealm.internalData.crafts, factionrealm.userData.craftingCooldownIgnore, char.internalData.craftingCooldowns
	-- [106] added global.userData.ungroupedItemMode
	-- [107] added global.tooltipOptions.{destroyTooltipFormat,convertTooltipFormat}, removed global.tooltipOptions.{deTooltip,millTooltip,prospectTooltip,transformTooltip,detailedDestroyTooltip}
	-- [108] updated global.tooltipOptions.moduleTooltips
	-- [109] updated global.craftingUIContext.professionScrollingTable
	-- [110] remove factionrealm.auctioningOptions.whitelist on retail
	-- [111] updated global.craftingUIContext.{professionScrollingTable,professionDividedContainer}
	-- [112] updated global.craftingUIContext.professionScrollingTable
	-- [113] updated global.craftingUIContext.professionDividedContainerBottom
	-- [114] updated factionrealm.internalData.crafts
	-- [115] removed global.internalData.optionalMatTextLookup
	-- [116] updated global.internalData.destroyingHistory
	-- [117] added global.storyBoardUIContext, updated global.craftingUIContext.{craftsScrollingTable,matsScrollingTable,gatheringScrollingTable}
	-- [118] updated factionrealm.internalData.crafts
	-- [119] added global.coreOptions.regionWide
	-- [120] rename global.userData.operations to global.userData.sharedOperations
	return Settings.NewSchema(120, 10)
		:EnterScope("global")
			:EnterNamespace("debug")
				:AddBoolean("chatLoggingEnabled", false, 19)
			:LeaveNamespace()
			:EnterNamespace("internalData")
				:AddString("lastCharacter", "???", 90)
				:AddTable("vendorItems", {}, 10)
				:AddNumber("appMessageId", 0, 10)
				:AddTable("destroyingHistory", {}, 116)
				:AddNumber("whatsNewVersion", 0, 94)
			:LeaveNamespace()
			:EnterNamespace("appearanceOptions")
				:AddBoolean("taskListBackgroundLock", false, 87)
				:AddBoolean("showTotalMoney", false, 95)
				:AddString("colorSet", "midnight", 75)
				:AddTable("customColorSet", {}, 98)
			:LeaveNamespace()
			:EnterNamespace("auctionUIContext")
				:AddTable("frame", { width = 830, height = 587, centerX = -300, centerY = 100, scale = 1, page = 1 }, 55)
				:AddBoolean("showDefault", false, 55)
				:AddTable("auctioningSelectionDividedContainer", { leftWidth = 272 }, 55)
				:AddTable("auctioningSelectionVerticalDividedContainer", { leftWidth = 220 }, 66)
				:AddTable("auctioningBagScrollingTable", { colWidth = { selected = 16, item = 246, operation = 206 }, colHidden = {} }, 55)
				:AddTable("auctioningLogScrollingTable", { colWidth = { index = 14, item = 190, buyout = 110, operation = 108, seller = 90, info = 234 }, colHidden = {} }, 55)
				:AddTable("auctioningAuctionScrollingTable", { colWidth = { item = 226, ilvl = 32, qty = ClientInfo.IsRetail() and 40 or nil, posts = not ClientInfo.IsRetail() and 40 or nil, stack = not ClientInfo.IsRetail() and 40 or nil, timeLeft = 26, seller = ClientInfo.IsRetail() and 136 or 88, itemBid = 115, bid = 115, itemBuyout = 115, buyout = 115, bidPct = 40, pct = 40 }, colHidden = { bid = true, buyout = true, bidPct = true } }, 103)
				:AddTable("myAuctionsScrollingTable", { colWidth = { item = 248, stackSize = 30, timeLeft = 40, highbidder = not ClientInfo.IsRetail() and 110 or nil, group = ClientInfo.IsRetail() and 228 or 110, currentBid = 100, buyout = 100 }, colHidden = {} }, 103)
				:AddTable("shoppingSelectionDividedContainer", { leftWidth = 272 }, 55)
				:AddTable("shoppingAuctionScrollingTable", { colWidth = { item = 226, ilvl = 32, qty = ClientInfo.IsRetail() and 40 or nil, posts = not ClientInfo.IsRetail() and 40 or nil, stack = not ClientInfo.IsRetail() and 40 or nil, timeLeft = 26, seller = ClientInfo.IsRetail() and 136 or 88, itemBid = 115, bid = 115, itemBuyout = 115, buyout = 115, bidPct = 40, pct = 40 }, colHidden = { bid = true, buyout = true, bidPct = true } }, 103)
				:AddTable("sniperScrollingTable", { colWidth = { icon = 24, item = 230, ilvl = 32, qty = ClientInfo.IsRetail() and 40 or nil, posts = not ClientInfo.IsRetail() and 40 or nil, stack = not ClientInfo.IsRetail() and 40 or nil, seller = ClientInfo.IsRetail() and 134 or 86, itemBid = 115, bid = 115, itemBuyout = 115, buyout = 115, bidPct = 40, pct = 40 }, colHidden = { bid = true, buyout = true, bidPct = true } }, 103)
				:AddTable("shoppingSearchesTabGroup", { pathIndex = 1 }, 55)
				:AddTable("auctioningTabGroup", { pathIndex = 1 }, 93)
			:LeaveNamespace()
			:EnterNamespace("bankingUIContext")
				:AddTable("frame", { width = 325, height = 600, centerX = 500, centerY = 0, scale = 1 }, 55)
				:AddBoolean("isOpen", true, 55)
				:AddString("tab", "Warehousing", 55)
			:LeaveNamespace()
			:EnterNamespace("craftingUIContext")
				:AddTable("frame", { width = 820, height = 587, centerX = -200, centerY = 0, scale = 1, page = 1 }, 55)
				:AddBoolean("showDefault", false, 55)
				:AddTable("craftsScrollingTable", { colWidth = { queued = 30, craftName = 222, operation = 80, bags = 28, ah = 24, craftingCost = 100, itemValue = 100, profit = 100, profitPct = 50, saleRate = 32 }, colHidden = { profitPct = true } }, 117)
				:AddTable("matsScrollingTable", { colWidth = { name = 246, price = 100, professions = 310, num = 100 }, colHidden = {} }, 117)
				:AddTable("gatheringDividedContainer", { leftWidth = 284 }, 55)
				:AddTable("gatheringScrollingTable", { colWidth = { name = 210, sources = 160, have = 50, need = 50 }, colHidden = {} }, 117)
				:AddTable("professionScrollingTable", { colWidth = { name = 310, qty = 54, craftingCost = 100, itemValue = 100, profit = 100, profitPct = 50, saleRate = 42 }, colHidden = { craftingCost = true, itemValue = true, profitPct = true }, collapsed = {} }, 112)
				:AddTable("professionDividedContainer", { leftWidth = 556 }, 111)
				:AddTable("professionDividedContainerBottom", { leftWidth = ClientInfo.IsRetail() and 348 or 390 }, 113)
			:LeaveNamespace()
			:EnterNamespace("destroyingUIContext")
				:AddTable("frame", { width = 296, height = 442, centerX = 0, centerY = 0, scale = 1 }, 55)
				:AddTable("itemsScrollingTable", { colWidth = { item = 214, num = 30 }, colHidden = {} }, 55)
			:LeaveNamespace()
			:EnterNamespace("storyBoardUIContext")
				:AddTable("frame", { width = 800, height = 600, centerX = 0, centerY = 0, scale = 1 }, 117)
			:LeaveNamespace()
			:EnterNamespace("mailingUIContext")
				:AddTable("frame", { width = 620, height = 516, centerX = -200, centerY = 0, scale = 1, page = 1 }, 55)
				:AddBoolean("showDefault", false, 55)
				:AddTable("mailsScrollingTable", { colWidth = { items = 380, sender = 100, expires = 65, money = 115 }, colHidden = { sender = true } }, 81)
			:LeaveNamespace()
			:EnterNamespace("mainUIContext")
				:AddTable("frame", { width = 900, height = 700, centerX = 0, centerY = 0, scale = 1, page = 1 }, 59)
				:AddTable("ledgerDetailScrollingTable", { colWidth = { activityType = 91, source = 60, buyerSeller = 100, qty = 45, perItem = 120, totalPrice = 120, time = 110 }, colHidden = {} }, 59)
				:AddTable("ledgerInventoryScrollingTable", { colWidth = { item = 160, totalItems = 50, bags = 50, banks = 50, mail = 50, alts = 50, guildVault = 50, auctionHouse = 50, totalValue = 120 }, colHidden = {} }, 69)
				:AddTable("ledgerAuctionsScrollingTable", { colWidth = { item = 305, player = 110, stackSize = 55, quantity = 72, time = 120 }, colHidden = {} }, 59)
				:AddTable("ledgerOtherScrollingTable", { colWidth = { type = 200, character = 110, otherCharacter = 122, amount = 120, time = 110 }, colHidden = {} }, 59)
				:AddTable("ledgerTransactionsScrollingTable", { colWidth = { item = 156, player = 95, type = 50, stack = 55, auctions = 60, perItem = 120, total = 120, time = 110 }, colHidden = { total = true } }, 62)
				:AddTable("ledgerResaleScrollingTable", { colWidth = { item = 194, bought = 50, avgBuyPrice = 120, sold = 50, avgSellPrice = 120, avgProfit = 120, totalProfit = 120, profitPct = 80 }, colHidden = { totalProfit = true, profitPct = true } }, 62)
				:AddTable("dashboardDividedContainer", { leftWidth = 300 }, 59)
				:AddTable("dashboardUnselectedCharacters", {}, 78)
				:AddNumber("dashboardTimeRange", -1, 78)
				:AddTable("groupsDividedContainer", { leftWidth = 300 }, 55)
				:AddTable("operationsDividedContainer", { leftWidth = 306 }, 55)
				:AddTable("importExportDividedContainer", { leftWidth = 300 }, 55)
				:AddTable("operationsSummaryScrollingTable", { colWidth = { selected = 16, name = 248, groups = 130, items = 130 }, colHidden = {} }, 76)
			:LeaveNamespace()
			:EnterNamespace("taskListUIContext")
				:AddTable("frame", { topRightX = -220, topRightY = -10, minimized = false, isOpen = true }, 55)
				:AddBoolean("isOpen", true, 55)
			:LeaveNamespace()
			:EnterNamespace("vendoringUIContext")
				:AddTable("frame", { width = 560, height = 500, centerX = -200, centerY = 0, scale = 1, page = 1 }, 55)
				:AddBoolean("showDefault", false, 55)
				:AddTable("buyScrollingTable", { colWidth = { qty = 40, item = 310, ilvl = 32, cost = 150 }, colHidden = { ilvl = true } }, 92)
				:AddTable("buybackScrollingTable", { colWidth = { qty = 40, item = 360, cost = 100 }, colHidden = {} }, 55)
				:AddTable("sellScrollingTable", { colWidth = { item = 300, vendorSell = 100, potential = 100 }, colHidden = {} }, 55)
			:LeaveNamespace()
			:EnterNamespace("coreOptions")
				:AddBoolean("globalOperations", false, 10)
				:AddBoolean("protectAuctionHouse", false, 77)
				:AddString("chatFrame", "", 10)
				:AddString("auctionSaleSound", Sound.GetNoSoundKey(), 10)
				:AddTable("minimapIcon", { hide = false, minimapPos = 220, radius = 80 }, 10)
				:AddString("destroyValueSource", "dbmarket", 10)
				:AddString("groupPriceSource", "dbmarket", 41)
				:AddBoolean("regionWide", false, 119)
			:LeaveNamespace()
			:EnterNamespace("accountingOptions")
				:AddBoolean("trackTrades", true, 10)
				:AddBoolean("autoTrackTrades", false, 10)
			:LeaveNamespace()
			:EnterNamespace("auctioningOptions")
				:AddBoolean("cancelWithBid", false, 10)
				:AddBoolean("disableInvalidMsg", false, 10)
				:AddBoolean("matchWhitelist", true, 10)
				:AddString("scanCompleteSound", Sound.GetNoSoundKey(), 10)
				:AddString("confirmCompleteSound", Sound.GetNoSoundKey(), 10)
			:LeaveNamespace()
			:EnterNamespace("craftingOptions")
				:AddString("defaultMatCostMethod", "min(dbmarket, crafting, vendorbuy, convert(dbmarket))", 10)
				:AddString("defaultCraftPriceMethod", "first(dbminbuyout, dbmarket)*0.95", 89)
				:AddTable("ignoreCharacters", {}, 10)
				:AddTable("ignoreGuilds", {}, 10)
			:LeaveNamespace()
			:EnterNamespace("destroyingOptions")
				:AddBoolean("autoStack", true, 10)
				:AddBoolean("includeSoulbound", false, 10)
				:AddBoolean("autoShow", true, 10)
				:AddNumber("deMaxQuality", 3, 10)
				:AddString("deAbovePrice", "0c", 10)
			:LeaveNamespace()
			:EnterNamespace("mailingOptions")
				:AddBoolean("sendItemsIndividually", false, 10)
				:AddBoolean("inboxMessages", true, 10)
				:AddBoolean("sendMessages", true, 10)
				:AddNumber("resendDelay", 1, 10)
				:AddNumber("keepMailSpace", 0, 10)
				:AddNumber("deMaxQuality", 2, 10)
				:AddString("openMailSound", Sound.GetNoSoundKey(), 10)
				:AddTable("recentlyMailedList", {}, 38)
			:LeaveNamespace()
			:EnterNamespace("shoppingOptions")
				:AddNumber("minDeSearchLvl", 1, 10)
				:AddNumber("maxDeSearchLvl", 500, 79)
				:AddNumber("maxDeSearchPercent", 100, 23)
				:AddString("pctSource", "dbmarket", 12)
				:AddBoolean("buyoutConfirm", false, 46)
				:AddString("buyoutAlertSource", "min(100000g, 200% dbmarket)", 46)
				:AddBoolean("searchAutoFocus", true, 88)
			:LeaveNamespace()
			:EnterNamespace("sniperOptions")
				:AddString("sniperSound", Sound.GetNoSoundKey(), 10)
			:LeaveNamespace()
			:EnterNamespace("vendoringOptions")
				:AddBoolean("displayMoneyCollected", false, 10)
				:AddString("qsMarketValue", "dbmarket", 10)
			:LeaveNamespace()
			:EnterNamespace("tooltipOptions")
				:AddBoolean("enabled", true, 20)
				:AddBoolean("embeddedTooltip", true, 10)
				:AddTable("customPriceTooltips", {}, 10)
				:AddTable("moduleTooltips", {}, 108)
				:AddBoolean("vendorBuyTooltip", true, 10)
				:AddBoolean("vendorSellTooltip", true, 10)
				:AddBoolean("groupNameTooltip", true, 10)
				:AddString("destroyTooltipFormat", "simple", 107)
				:AddString("convertTooltipFormat", "simple", 107)
				:AddTable("operationTooltips", {}, 10)
				:AddString("tooltipShowModifier", "none", 10)
				:AddString("inventoryTooltipFormat", "full", 10)
				:AddString("tooltipPriceFormat", "text", 10)
			:LeaveNamespace()
			:EnterNamespace("userData")
				:AddTable("sharedOperations", {}, 120)
				:AddTable("customPriceSources", {}, 10)
				:AddTable("destroyingIgnore", {}, 10)
				:AddTable("savedShoppingSearches", { filters = {}, name = {}, isFavorite = {} }, 96)
				:AddTable("vendoringIgnore", {}, 10)
				:AddTable("savedAuctioningSearches", { filters = {}, searchTypes = {}, name = {}, isFavorite = {} }, 96)
				:AddString("ungroupedItemMode", "specific", 106)
			:LeaveNamespace()
		:LeaveScope()
		:EnterScope("profile")
			:EnterNamespace("internalData")
				:AddBoolean("createdDefaultOperations", false, 11)
			:LeaveNamespace()
			:EnterNamespace("userData")
				:AddTable("groups", {}, 10)
				:AddTable("items", {}, 10)
				:AddTable("operations", {}, 10)
			:LeaveNamespace()
			:EnterNamespace("gatheringOptions")
				:AddTable("sources", { "vendor", "guildBank", "alt", "altGuildBank", "craftProfit", "auction", "craftNoProfit" }, 32)
			:LeaveNamespace()
		:LeaveScope()
		:EnterScope("factionrealm")
			:EnterNamespace("internalData")
				:AddTable("characterGuilds", {}, 10)
				:AddTable("guildVaults", {}, 10)
				:AddTable("pendingMail", {}, 10)
				:AddTable("expiringMail", {}, 47)
				:AddTable("expiringAuction", {}, 47)
				:AddString("mailDisenchantablesChar", "", 49)
				:AddString("mailExcessGoldChar", "", 49)
				:AddNumber("mailExcessGoldLimit", 10000000000, 49)
				:AddTable("crafts", {}, 118)
				:AddTable("craftingQueue", {}, 101)
				:AddTable("mats", {}, 10)
				:AddTable("guildGoldLog", {}, 25)
				:AddTable("guildGoldLogLastUpdate", {}, 83)
				:AddTable("isCraftFavorite", {}, 56)
			:LeaveNamespace()
			:EnterNamespace("coreOptions")
				:AddTable("ignoreGuilds", {}, 10)
			:LeaveNamespace()
			:EnterNamespace("auctioningOptions")
				:If(not ClientInfo.IsRetail())
					:AddTable("whitelist", {}, 10)
				:EndIf()
			:LeaveNamespace()
			:EnterNamespace("gatheringContext")
				:AddString("crafter", "", 32)
				:AddTable("professions", {}, 32)
			:LeaveNamespace()
			:EnterNamespace("userData")
				:AddTable("craftingCooldownIgnore", {}, 105)
			:LeaveNamespace()
		:LeaveScope()
		:EnterScope("realm")
			:EnterNamespace("internalData")
				:AddString("csvSales", "", 10)
				:AddString("csvBuys", "", 10)
				:AddString("csvIncome", "", 10)
				:AddString("csvExpense", "", 10)
				:AddString("csvExpired", "", 10)
				:AddString("csvCancelled", "", 10)
				:AddString("saveTimeSales", "", 10)
				:AddString("saveTimeBuys", "", 10)
				:AddString("saveTimeExpires", "", 10)
				:AddString("saveTimeCancels", "", 10)
				:AddTable("accountingTrimmed", {}, 10)
			:LeaveNamespace()
		:LeaveScope()
		:EnterScope("char")
			:EnterNamespace("internalData")
				:AddTable("auctionPrices", {}, 10)
				:AddTable("auctionMessages", {}, 10)
				:AddTable("craftingCooldowns", {}, 105)
				:AddTable("auctionSaleHints", {}, 45)
			:LeaveNamespace()
			:EnterNamespace("auctionUIContext")
				:AddTable("auctioningGroupTree", { collapsed = {}, unselected = {} }, 80)
				:AddTable("shoppingGroupTree", { collapsed = {}, unselected = {} }, 80)
			:LeaveNamespace()
			:EnterNamespace("bankingUIContext")
				:AddTable("warehousingGroupTree", { collapsed = {}, unselected = {} }, 80)
				:AddTable("auctioningGroupTree", { collapsed = {}, unselected = {} }, 80)
				:AddTable("mailingGroupTree", { collapsed = {}, unselected = {} }, 80)
			:LeaveNamespace()
			:EnterNamespace("craftingUIContext")
				:AddTable("groupTree", { collapsed = {}, unselected = {} }, 80)
			:LeaveNamespace()
			:EnterNamespace("mailingUIContext")
				:AddTable("groupTree", { collapsed = {}, unselected = {} }, 80)
			:LeaveNamespace()
			:EnterNamespace("vendoringUIContext")
				:AddTable("groupTree", { collapsed = {}, unselected = {} }, 80)
			:LeaveNamespace()
			:EnterNamespace("mainUIContext")
				:AddTable("groupsManagementGroupTree", { collapsed = {} }, 71)
				:AddTable("importGroupTree", { collapsed = {}, selected = {} }, 80)
				:AddTable("exportGroupTree", { collapsed = {}, unselected = {} }, 80)
			:LeaveNamespace()
		:LeaveScope()
		:EnterScope("sync")
			-- NOTE: whenever these are changed, the sync version needs to be increased in LibTSM/Services/SyncClasses/Constants.lua
			:EnterNamespace("internalData")
				:AddNumber("money", 0, 74)
				:AddString("classKey", "", 19)
				:AddTable("bagQuantity", {}, 19)
				:AddTable("bankQuantity", {}, 19)
				:AddTable("reagentBankQuantity", {}, 19)
				:AddTable("auctionQuantity", {}, 19)
				:AddTable("mailQuantity", {}, 19)
				:AddString("goldLog", "", 25)
				:AddNumber("goldLogLastUpdate", 0, 83)
				:AddTable("playerProfessions", {}, 36)
			:LeaveNamespace()
		:LeaveScope()
		:Commit()
end

function private.ProcessUpgrade(db, upgradeObj)
	local prevVersion = upgradeObj:GetPrevVersion()
	if prevVersion < 19 then
		-- migrate inventory data to the sync scope
		local oldInventoryData = TempTable.Acquire()
		local oldSyncMetadata = TempTable.Acquire()
		local oldAccountKey = TempTable.Acquire()
		local oldCharacters = TempTable.Acquire()
		for _, key, value in upgradeObj:RemovedSettingIterator("factionrealm", nil, nil, "inventory") do
			oldInventoryData[upgradeObj:GetScopeKey(key)] = value
		end
		for _, key, value in upgradeObj:RemovedSettingIterator("factionrealm", nil, nil, "syncMetadata") do
			oldSyncMetadata[upgradeObj:GetScopeKey(key)] = value
		end
		for _, key, value in upgradeObj:RemovedSettingIterator("factionrealm", nil, nil, "accountKey") do
			oldAccountKey[upgradeObj:GetScopeKey(key)] = value
		end
		for _, key, value in upgradeObj:RemovedSettingIterator("factionrealm", nil, nil, "characters") do
			oldCharacters[upgradeObj:GetScopeKey(key)] = value
		end
		for factionrealm, characters in pairs(oldInventoryData) do
			local syncMetadata = oldSyncMetadata[factionrealm] and oldSyncMetadata[factionrealm].TSM_CHARACTERS
			for character, inventoryData in pairs(characters) do
				if not syncMetadata or not syncMetadata[character] or syncMetadata[character].owner == oldAccountKey[factionrealm] then
					db:NewSyncCharacter(db:GetLocalSyncAccountKey(factionrealm), character, factionrealm)
					local syncScopeKey = db:GetSyncScopeKeyByCharacter(character, factionrealm)
					local class = oldCharacters[factionrealm] and oldCharacters[factionrealm][character]
					if type(class) == "string" then
						db:Set("sync", syncScopeKey, "internalData", "classKey", class)
					end
					db:Set("sync", syncScopeKey, "internalData", "bagQuantity", inventoryData.bag)
					db:Set("sync", syncScopeKey, "internalData", "bankQuantity", inventoryData.bank)
					db:Set("sync", syncScopeKey, "internalData", "reagentBankQuantity", inventoryData.reagentBank)
					db:Set("sync", syncScopeKey, "internalData", "auctionQuantity", inventoryData.auction)
					db:Set("sync", syncScopeKey, "internalData", "mailQuantity", inventoryData.mail)
				end
			end
		end
		TempTable.Release(oldInventoryData)
		TempTable.Release(oldSyncMetadata)
		TempTable.Release(oldAccountKey)
		TempTable.Release(oldCharacters)
	end
	if prevVersion < 25 then
		-- migrate gold log info
		local NEW_CSV_COLS = { "minute", "copper" }
		local function ConvertGoldLogFormat(data)
			local decodedData = select(2, CSV.Decode(data))
			if not decodedData then
				return
			end
			for _, entry in ipairs(decodedData) do
				local minute = entry.startMinute
				local copper = entry.copper
				wipe(entry)
				entry.minute = minute
				entry.copper = copper
			end
			return CSV.Encode(NEW_CSV_COLS, decodedData)
		end
		local GOLD_LOG_FACTIONS = {
			"Horde",
			"Alliance",
			"Neutral",
		}
		local function ProcessGoldLogData(character, data, realm)
			if type(data) ~= "string" then
				return
			end
			-- check if we know about this character and under what faction
			local syncScopeKey = nil
			for _, faction in ipairs(GOLD_LOG_FACTIONS) do
				local factionrealm = faction.." - "..realm
				local testSyncScopeKey = db:GetSyncScopeKeyByCharacter(character, factionrealm)
				if db:Get("sync", testSyncScopeKey, "internalData", "classKey") then
					syncScopeKey = testSyncScopeKey
				end
			end
			if syncScopeKey then
				db:Set("sync", syncScopeKey, "internalData", "goldLog", ConvertGoldLogFormat(data))
			else
				-- check if this is a known guild
				local found = false
				for _, faction in ipairs(GOLD_LOG_FACTIONS) do
					local factionrealm = faction.." - "..realm
					local characterGuilds = db:Get("factionrealm", factionrealm, "internalData", "characterGuilds")
					if not found and characterGuilds and Table.KeyByValue(characterGuilds, character) then
						local guildGoldLog = db:Get("factionrealm", factionrealm, "internalData", "guildGoldLog") or {}
						guildGoldLog[character] = ConvertGoldLogFormat(data)
						db:Set("factionrealm", factionrealm, "internalData", "guildGoldLog", guildGoldLog)
						found = true
					end
				end
			end
		end
		for _, key, value in upgradeObj:RemovedSettingIterator("realm", nil, nil, "goldLog") do
			local scopeKey = upgradeObj:GetScopeKey(key)
			for character, data in pairs(value) do
				ProcessGoldLogData(character, data, scopeKey)
			end
		end
	end
	if prevVersion < 36 then
		for _, key, value in upgradeObj:RemovedSettingIterator("factionrealm", nil, nil, "playerProfessions") do
			local factionrealm = upgradeObj:GetScopeKey(key)
			for character, data in pairs(value) do
				-- check if we know about this character
				local syncScopeKey = db:GetSyncScopeKeyByCharacter(character, factionrealm)
				if db:Get("sync", syncScopeKey, "internalData", "classKey") then
					db:Set("sync", syncScopeKey, "internalData", "playerProfessions", data)
				end
			end
		end
	end
	if prevVersion < 64 then
		local hadValue = false
		for _, _, value in upgradeObj:RemovedSettingIterator("global", nil, "accountingOptions", "smartBuyPrice") do
			hadValue = hadValue or value
		end
		if hadValue then
			-- show a dialog to inform the user that this was removed
			StaticPopupDialog.ShowWithOk(L["The 'use smart average for purchase price' setting has been removed from TSM and replaced with a new 'SmartAvgBuy' price source. Please update your custom prices appropriately."])
		end
	end
	if prevVersion < 82 then
		for _, key, value in upgradeObj:RemovedSettingIterator("global", nil, "craftingUIContext", "professionScrollingTable") do
			-- preserve the previous values
			local newTbl = db:Get("global", upgradeObj:GetScopeKey(key), "craftingUIContext", "professionScrollingTable")
			for col, width in pairs(value.colWidth) do
				newTbl.colWidth[col] = width
			end
			for col, hidden in pairs(value.colHidden) do
				newTbl.colHidden[col] = hidden
			end
			if value.collapsed then
				for col, collapsed in pairs(value.collapsed) do
					newTbl.collapsed[col] = collapsed
				end
			end
		end
	end
	if prevVersion < 89 then
		for _, key, value in upgradeObj:RemovedSettingIterator("global", nil, "craftingOptions", "defaultCraftPriceMethod") do
			-- preserve the previous value
			db:Set("global", upgradeObj:GetScopeKey(key), "craftingOptions", "defaultCraftPriceMethod", value)
		end
	end
	if prevVersion < 96 then
		for _, key, value in upgradeObj:RemovedSettingIterator("global", nil, "userData", "savedShoppingSearches") do
			-- convert how they are stored
			local newTbl = db:Get("global", upgradeObj:GetScopeKey(key), "userData", "savedShoppingSearches")
			for i, searchInfo in ipairs(value) do
				local filter = searchInfo.filter
				if searchInfo.name ~= filter then
					newTbl.name[filter] = searchInfo.name
				end
				if searchInfo.isFavorite then
					newTbl.isFavorite[filter] = true
				end
				newTbl.filters[i] = filter
			end
		end

		for _, key, value in upgradeObj:RemovedSettingIterator("global", nil, "userData", "savedAuctioningSearches") do
			-- convert how they are stored
			local newTbl = db:Get("global", upgradeObj:GetScopeKey(key), "userData", "savedAuctioningSearches")
			for i, searchInfo in ipairs(value) do
				local filter = searchInfo.filter
				if searchInfo.name ~= filter then
					newTbl.name[filter] = searchInfo.name
				end
				if searchInfo.isFavorite then
					newTbl.isFavorite[filter] = true
				end
				newTbl.filters[i] = filter
				newTbl.searchTypes[i] = searchInfo.searchType
			end
		end
	end
	if prevVersion < 105 and ClientInfo.IsRetail() then
		for _, key, value in upgradeObj:RemovedSettingIterator("factionrealm", nil, "userData", "craftingCooldownIgnore") do
			if prevVersion < 99 then
				local IGNORED_COOLDOWN_SEP = "\001"
				local newValue = {}
				for entry in pairs(value) do
					local characterKey, spellId = strsplit(IGNORED_COOLDOWN_SEP, entry)
					newValue[characterKey..IGNORED_COOLDOWN_SEP.."c:"..spellId] = true
				end
				value = newValue
			end
			db:Set("factionrealm", upgradeObj:GetScopeKey(key), "userData", "craftingCooldownIgnore", value)
		end
		for _, key, value in upgradeObj:RemovedSettingIterator("char", nil, "internalData", "craftingCooldowns") do
			if prevVersion < 99 then
				local newValue = {}
				for spellId, data in pairs(value) do
					newValue["c:"..spellId] = data
				end
				value = newValue
			end
			db:Set("char", upgradeObj:GetScopeKey(key), "internalData", "craftingCooldowns", value)
		end
	end
	if prevVersion < 108 then
		for _, key, value in upgradeObj:RemovedSettingIterator("global", nil, "tooltipOptions", "moduleTooltips") do
			-- update AuctionDB.{marketValue,regionMarketValue} values
			if value.AuctionDB then
				value.AuctionDB.marketValue = value.AuctionDB.marketValue and "withTrend" or "none"
				value.AuctionDB.regionMarketValue = value.AuctionDB.regionMarketValue and "noTrend" or "none"
			end
			db:Set("global", upgradeObj:GetScopeKey(key), "tooltipOptions", "moduleTooltips", value)
		end
	end
	if prevVersion < 118 then
		if ClientInfo.IsRetail() then
			for _, key, value in upgradeObj:RemovedSettingIterator("factionrealm", nil, "internalData", "crafts") do
				if prevVersion < 99 then
					local newValue = {}
					for spellId, data in pairs(value) do
						newValue["c:"..spellId] = data
					end
					value = newValue
				end
				if prevVersion < 114 then
					for _, craft in pairs(value) do
						if craft.mats then
							for itemString in pairs(craft.mats) do
								if strmatch(itemString, "^o:") then
									craft.mats[itemString] = 1
								end
							end
						end
					end
				end
				for _, craft in pairs(value) do
					for _, info in pairs(craft.players) do
						if type(info) == "table" and info.baseRecipeDifficulty then
							info.inspirationAmount = 0
							info.inspirationChance = 0
						end
					end
				end
				db:Set("factionrealm", upgradeObj:GetScopeKey(key), "internalData", "crafts", value)
			end
		else
			if prevVersion >= 105 then
				for _, key, value in upgradeObj:RemovedSettingIterator("factionrealm", nil, "internalData", "crafts") do
					db:Set("factionrealm", upgradeObj:GetScopeKey(key), "internalData", "crafts", value)
				end
			end
		end
	end
	if prevVersion < 120 then
		for _, key, value in upgradeObj:RemovedSettingIterator("global", nil, "userData", "operations") do
			db:Set("global", upgradeObj:GetScopeKey(key), "userData", "sharedOperations", value)
		end
	end
	-- NOTE: When adding migrations, be careful of multiple migrations modifying the same key, as
	-- the RemovedSettingIterator value could be stale.
end
