-- ------------------------------------------------------------------------------ --
--                                TradeSkillMaster                                --
--                          https://tradeskillmaster.com                          --
--    All Rights Reserved - Detailed license information included with addon.     --
-- ------------------------------------------------------------------------------ --

local TSM = select(2, ...) ---@type TSM
local Migration = TSM.Init("Service.SettingsClasses.Migration") ---@class Service.SettingsClasses.Migration
local Types = TSM.Include("Service.SettingsClasses.Types")
local TempTable = TSM.LibTSMUtil:Include("BaseType.TempTable")
local String = TSM.LibTSMUtil:Include("Lua.String")
local LibTSMClass = TSM.Include("LibTSMClass")
local SettingsMigration = LibTSMClass.DefineClass("SettingsMigration") ---@class SettingsMigration



-- ============================================================================
-- Module Functions
-- ============================================================================

---Creates a new migration object.
---@param prevVersion number The previous DB version
---@param removedSettings table<string, any> Removed setting values
---@return SettingsMigration
function Migration.Create(prevVersion, removedSettings)
	return SettingsMigration(prevVersion, removedSettings)
end



-- ============================================================================
-- Class Meta Methods
-- ============================================================================

function SettingsMigration:__init(prevVersion, removedSettings)
	self._prevVersion = prevVersion
	self._removedSettings = removedSettings
end



-- ============================================================================
-- Public Class Methods
-- ============================================================================

function SettingsMigration:GetPrevVersion()
	return self._prevVersion
end

function SettingsMigration:RemovedSettingIterator(filterScopeType, filterScopeKey, filterNamespace, filterSettingKey)
	assert(not filterScopeType or Types.SCOPES[filterScopeType])
	filterScopeType = filterScopeType and Types.SCOPES[filterScopeType] or ".+"
	filterScopeKey = filterScopeKey and String.Escape(filterScopeKey) or ".+"
	filterNamespace = filterNamespace and String.Escape(filterNamespace) or ".+"
	filterSettingKey = filterSettingKey and String.Escape(filterSettingKey) or ".+"
	local keyFilter = "^"..strjoin(Types.KEY_SEP, filterScopeType, filterScopeKey, filterNamespace, filterSettingKey).."$"
	local result = TempTable.Acquire()
	for key, value in pairs(self._removedSettings) do
		if strmatch(key, keyFilter) then
			tinsert(result, key)
			tinsert(result, value)
		end
	end
	return TempTable.Iterator(result, 2)
end

function SettingsMigration:GetKeyInfo(key)
	local scopeType, scopeKey, namespace, settingKey, extraPart = strsplit(Types.KEY_SEP, key)
	assert(settingKey and not extraPart)
	scopeType = Types.SCOPES_LOOKUP[scopeType]
	return scopeType, scopeKey, namespace, settingKey
end

function SettingsMigration:GetScopeKey(key)
	local scopeKey = strmatch(key, "^.+@(.+)@.+@.+$")
	assert(scopeKey)
	return scopeKey
end
