-- ------------------------------------------------------------------------------ --
--                                TradeSkillMaster                                --
--                          https://tradeskillmaster.com                          --
--    All Rights Reserved - Detailed license information included with addon.     --
-- ------------------------------------------------------------------------------ --

local LibTSMUtil = select(2, ...).LibTSMUtil
local UIManager = LibTSMUtil:DefineClassType("UIManager")



-- ============================================================================
-- Static Class Functions
-- ============================================================================

---Creates a new UI manager object.
---@param state ReactiveState
---@param actionHandler fun(state: ReactiveState, action: string)
---@return UIManager
function UIManager.__static.Create(state, actionHandler)
	return UIManager(state, actionHandler)
end



-- ============================================================================
-- Meta Class Methods
-- ============================================================================

function UIManager.__private:__init(state, actionHandler)
	self._state = state
	self._actionHandler = actionHandler
	self._cancellables = {}
end



-- ============================================================================
-- Public Class Methods
-- ============================================================================

---Sets up a publisher to assign any published values to the state.
---@param publisher ReactivePublisher The settings view
---@param key string The key to set in the state
function UIManager:SetStateFromPublisher(key, publisher)
	self:AddCancellable(publisher:AssignToTableKey(self._state, key))
end

---Adds a cancellable to be owned by the manager.
---@param publisher ReactivePublisher
function UIManager:AddCancellable(publisher)
	publisher:StoreIn(self._cancellables)
end

---Processes an action whenever a value is published.
---@param action string The action to be processed
---@param publisher ReactivePublisher The publisher
function UIManager:ProcessActionFromPublisher(action, publisher)
	publisher
		:MapToValue(action)
		:CallMethod(self, "ProcessAction")
		:StoreIn(self._cancellables)
end

---Processes an action.
---@param action string
function UIManager:ProcessAction(action)
	while action do
		action = self._actionHandler(self._state, action)
	end
end
